--- a/app/soc/logic/validate.py Thu Nov 20 18:50:30 2008 +0000
+++ b/app/soc/logic/validate.py Thu Nov 20 19:43:31 2008 +0000
@@ -56,15 +56,15 @@
return False
-def isPartialPathFormatValid(partial_path):
- """Returns True if partial_path is in a valid format.
+def isScopePathFormatValid(scope_path):
+ """Returns True if scope_path is in a valid format.
Args:
partial_path: partial path prepended to link ID
used for identification.
"""
- if path_link_name.PARTIAL_PATH_REGEX.match(partial_path):
+ if path_link_name.SCOPE_PATH_REGEX.match(scope_path):
return True
return False
@@ -56,15 +56,15 @@
Args:
- partial_path: partial path prepended to link ID
+ scope_path: scope path prepended to link ID
used for identification.
"""